/*******************************************************************************
* Copyright (C) 2019 China Micro Semiconductor Limited Company. All Rights Reserved.
*
* This software is owned and published by:
* CMS LLC, No 2609-10, Taurus Plaza, TaoyuanRoad, NanshanDistrict, Shenzhen, China.
*
* BY DOWNLOADING, INSTALLING OR USING THIS SOFTWARE, YOU AGREE TO BE BOUND
* BY ALL THE TERMS AND CONDITIONS OF THIS AGREEMENT.
*
* This software contains source code for use with CMS
* components. This software is licensed by CMS to be adapted only
* for use in systems utilizing CMS components. CMS shall not be
* responsible for misuse or illegal use of this software for devices not
* supported herein. CMS is providing this software "AS IS" and will
* not be responsible for issues arising from incorrect user implementation
* of the software.
*
* This software may be replicated in part or whole for the licensed use,
* with the restriction that this Disclaimer and Copyright notice must be
* included with each copy of this software, whether used in part or whole,
* at all times.
*/

/****************************************************************************/
/** \file fmc.c
**
**	History:
**	
*****************************************************************************/
/****************************************************************************/
/*	include files
*****************************************************************************/
#include "fmc.h"
/****************************************************************************/
/*	Local pre-processor symbols/macros('#define')
*****************************************************************************/

/****************************************************************************/
/*	Global variable definitions(declared in header file with 'extern')
*****************************************************************************/

/****************************************************************************/
/*	Local type definitions('typedef')
*****************************************************************************/

/****************************************************************************/
/*	Local variable  definitions('static')
*****************************************************************************/


/****************************************************************************/
/*	Local function prototypes('static')
*****************************************************************************/

/****************************************************************************/
/*	Function implementation - global ('extern') and local('static')
*****************************************************************************/

/*****************************************************************************
 ** \brief	FMC_ErasePage
 **			FMC ҳ
 ** \param [in] PageAddr: 
 ** \return  none
 ** \note	
*****************************************************************************/
void FMC_ErasePage(uint32_t PageAddr)
{
	__DI;
	FMC->LOCK = FMC_WRITE_KEY;
	FMC->ADR = PageAddr;
	FMC->CMD = FMC_CMD_PAGE_ERASE;
	while(FMC_IS_BUSY());
	FMC->LOCK = 0x00;	
	__EI;
}

/*****************************************************************************
 ** \brief	FMC_Read
 **			FMC 
 ** \param [in] DataAddrַλΪ0
 ** \return  32λ
 ** \note	
*****************************************************************************/
uint32_t FMC_Read(uint32_t DataAddr)
{
	uint32_t FlashData;
	FMC->LOCK = FMC_WRITE_KEY;
	FMC->ADR = (DataAddr & 0xFFFFFFFC);
	FMC->CMD = FMC_CMD_READ;
	FlashData = FMC->DAT;
	while(FMC_IS_BUSY());
	FMC->LOCK = 0x00;
	return FlashData;
}

/*****************************************************************************
 ** \brief	FMC_Write
 **			FMC д
 ** \param [in] DataAddrַλΪ0
 **				DataVlue: 32λ
 ** \return  none
 ** \note	
*****************************************************************************/
void FMC_Write(uint32_t DataAddr, uint32_t DataVlue)
{
	__DI;
	FMC->LOCK = FMC_WRITE_KEY;
	FMC->ADR = (DataAddr & 0xFFFFFFFC);
	FMC->DAT = DataVlue;
	FMC->CMD = FMC_CMD_WRITE;
	while(FMC_IS_BUSY());
	FMC->LOCK = 0x00;
	__EI;
}

int ProgramPage (unsigned long adr, unsigned long sz, unsigned char *buf) 
{
	
	__DI;
	FMC->LOCK = FMC_WRITE_KEY;
	while (sz) 
	{		
		FMC->ADR = (adr & 0xFFFFFFFC);
		FMC->DAT = *((unsigned long *)buf);;
		FMC->CMD = FMC_CMD_WRITE;
		
		adr += 4;
		buf += 4;
		sz  -= 4;
	}
		while(FMC_IS_BUSY());
		FMC->LOCK = 0x00;	
	__EI;
	
  /* Add your Code */
  return (0);                                  // Finished without Errors
}

/*****************************************************************************
 ** \brief	FMC_CRC
 **			FMC CRCУ
 ** \param [in] CRCStartAddr:	  CRCУʼַ
 **				CRCStopAddr:	  CRCУַ
 ** \return  none
 ** \note	 ֻAPROM
*****************************************************************************/
uint16_t FMC_CRC(uint32_t CRCStartAddr, uint32_t CRCStopAddr)
{
	uint16_t CrcResult;
	FMC->LOCK = FMC_WRITE_KEY;
	FMC->ADR = CRCStartAddr & 0xFFFFFFFC;
	FMC->CRCEA = CRCStopAddr & 0xFFFFFFFC;
	FMC->CRCIN = 0x00;
	FMC->CRCD = 0x00;
	FMC->CMD = FMC_CMD_CRC;
	CrcResult = FMC->CRCD;	
	FMC->LOCK = 0x00;
	return CrcResult;
}
